"use client";

import * as echarts from "echarts";
import { useEffect, useRef, useState } from "react";
import webviewBaseRequest from "@/utils/webviewBaseRequest";
import { generateSignature } from "@/utils/crypto";
export default function IncomeQuerry() {
  var databoard = useRef();
  var incomeOrgin = useRef();
  const [data, setData] = useState({
    withdraw_diamonds: 0,
    today_income: 0,
    wait_deal_income: 0,
    weekIncom: 0,
  });
  useEffect(() => {
    getData();
  }, []);
  useEffect(() => {
    if(databoard.current&&data.week_dashboard){
      createDataBoard(data.week_dashboard);
    }
  }, [databoard.current,data]);
  useEffect(() => {
    if(incomeOrgin.current && data.income_from_dashboard){
      createIncomeOrgin(data.income_from_dashboard);
    }
  }, [incomeOrgin.current,data]);
  const getData = async () => {
    const base = webviewBaseRequest();
    const signature = generateSignature({
      ...base,
    });
    try {
      const response = await fetch(
        `/api/vas/income_page?signature=${signature}`,
        {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            ...base,
          }),
        }
      );
      const { data } = await response.json();
      const weekIncom = data.week_dashboard.reduce((total, item) => {
        return total + item.income;
      }, 0);
      data && setData({ ...data, weekIncom });
      
    } catch (error) {}
  };

  const createDataBoard = (data) => {
      var myChart = echarts.init(databoard.current, "dark");
      var option;
      option = {
        backgroundColor: {
          type: "radial",
          x: 0.3,
          y: 0.3,
          r: 0.8,
          colorStops: [
            {
              offset: 0,
              color: "#ffffff00",
            },
            {
              offset: 1,
              color: "#ffffff00",
            },
          ],
        },
        // tooltip: {
        //   trigger: 'axis'
        // },
        tooltip: {
          trigger: 'axis',
          formatter: '{b} : {c}'
        },
        xAxis: {
          type: "category",
          boundaryGap: false,
          data: getDateStr(data),
        },
        yAxis: {
          splitLine: {
            // show: false,
            lineStyle: {
              type: "dashed",
              color: "#ffffff30",
              // ...
            },
          },
          type: "value",
        },
        grid: {
          top: "8%",
          left: "3%",
          right: "4%",
          bottom: "3%",
          containLabel: true,
        },
        series: [
          {
            name: '',
            symbolSize: 10,
            data:data.map(item=>item.income),
            type: "line",
            stack: 'Total',
            lineStyle: {
              color: "#ffffff",
              // ...
            },
            itemStyle: {
              color: "#fff",
              backgroundColor: "#fff",
            },
          },
        ],
      };
      option && myChart.setOption(option);
  };
  const createIncomeOrgin = (data) => {
      var myChart = echarts.init(incomeOrgin.current, "dark");
      var option;
      option = {
        backgroundColor: {
          type: "radial",
          x: 0.3,
          y: 0.3,
          r: 0.8,
          colorStops: [
            {
              offset: 0,
              color: "#ffffff00",
            },
            {
              offset: 1,
              color: "#ffffff00",
            },
          ],
        },
        tooltip: {
          trigger: "item",
        },
        legend: {
          type: "scroll",
          orient: "vertical",
          right: 10,
          top: 32,
          bottom: 20,
          color: "#fff",
          // data: data.legendData
        },
        series: [
          {
            name: "",
            type: "pie",
            radius: ["40%", "70%"],
            center: ["30%", "50%"],
            avoidLabelOverlap: false,
            padAngle: 5,
            itemStyle: {
              borderRadius: 10,
            },
            label: {
              show: false,
              position: "center",
            },
            emphasis: {
              label: {
                show: false,
                fontSize: 40,
                fontWeight: "bold",
              },
            },
            labelLine: {
              show: false,
            },
            data: data.map(item=>({value:item.income,name:item.desc})),
          },
        ],
      };
      option && myChart.setOption(option);
  };

  const getDateStr = (data) => {
    return data.map(item=>{
      let newTimeStr = `${item.date.slice(0,4)}-${item.date.slice(4,6)}-${item.date.slice(6,8)}`
      return (new Date(newTimeStr).getMonth() + 1)+"."+(new Date(newTimeStr).getDate())
    }) 
      
  };
  return (
    <div className="w-full">
      <p className="text-xs my-2">*当前页面所有统计单位均为钻石</p>
      <div className="rounded-2xl bg-gradient-to-r from-[#FF668B] to-[#FF66F0] text-white p-4 h-max mb-4">
        <div className="mb-4">
          <p className=" text-lg mb-4 font-medium">可提现钻石</p>
          <div className="flex justify-between items-center">
            <span className="text-3xl font-bold">{data.withdraw_diamonds}</span>
            {/* <Link href={"#"} className="text-sm text-[#7d304c]">
              <span>前往提现</span>
            </Link> */}
          </div>
        </div>
        <div className="grid grid-cols-3 items-center">
          <div className="text-center">
            <p className="text-sm">今日收益</p>
            <p className="text-lg font-bold">{data.today_income}</p>
          </div>
          <div className="text-center">
            <p className="text-sm">待结算收益</p>
            <p className="text-lg font-bold">{data.wait_deal_income}</p>
          </div>
          <div className="text-center">
            <p className="text-sm">近一周收益</p>
            <p className="text-lg font-bold">{data.weekIncom}</p>
          </div>
        </div>
      </div>

      <div className="mt-4">
        {(data.week_dashboard || data.income_from_dashboard) && <p className="text-xs my-2">*以下所有数据均为次日00:10更新</p>}
        {
          data.week_dashboard &&
          <div className="rounded-2xl bg-gradient-to-b from-[#ff668c80] to-[#FF668B30] text-white mb-4 p-4">
          <p className="text-lg mb-4 font-medium">数据看板</p>
          <div className="h-40" ref={databoard}></div>
        </div>
        }
        {
          data.income_from_dashboard &&
          <div className="rounded-2xl bg-gradient-to-b from-[#ff668c80] to-[#FF668B30] text-white mb-4 p-4">
          <p className="text-lg mb-4 font-medium text-white">收益来源</p>
          <div className="h-40" ref={incomeOrgin}></div>
        </div>
        }
      </div>
    </div>
  );
}
